@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.9 2000/03/21 11:03:36 fredgo Exp $
+# $Id: Base.py,v 1.10 2000/04/06 07:11:03 fredgo Exp $
 
 from string import *
 import re, copy, os
@@ -220,6 +220,12 @@ class DataBase:
 	return self.dict.has_key (key)
 
 
+    def would_have_key (self, key):
+        ''' Test for a key that would be set on the database '''
+
+        return self.has_key (Key.Key (self, key.key))
+
+    
     def __getitem__ (self, key):
 	''' Returns the Entry object associated with the key '''
 
@@ -229,6 +235,7 @@ class DataBase:
     def __setitem__ (self, key, value):
 	''' Sets a key Entry '''
 
+        key.base  = self.key
         value.key = key
 	self.dict [key] = value
 	return
