@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: BibTeX.py,v 1.15 2000/03/15 08:36:32 fredgo Exp $
+# $Id: BibTeX.py,v 1.17 2000/04/04 08:33:46 fredgo Exp $
 
 # Extension module for BibTeX files
 
@@ -90,7 +90,10 @@ class Entry (Base.Entry):
 
             day   = None
 	    month = None
-	    year  = int (self [yearfield].text)
+            try:
+                year = int (self [yearfield].text)
+            except ValueError:
+                break
             
 	    del self [yearfield]
 
@@ -205,7 +208,8 @@ class Entry (Base.Entry):
         self.key    = state.key
         self.__text = state.dict
         self.parser = _unpickle_db
-
+        self.line   = 0
+        
         for field in state.keys ():
             self [field] = state [field]
         return
