@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.13 2000/04/04 08:32:56 fredgo Exp $
+# $Id: Editor.py,v 1.15 2000/04/07 15:45:40 fredgo Exp $
 
 import string, re
 from gnome.ui import *
@@ -237,7 +237,6 @@ class Date (BaseField):
     
     def create_widget (self, h):
         hbox = GtkHBox (FALSE, 5)
-        #hbox.set_border_width (5)
 
         self.day = GtkEntry ()
         (width, height) = self.day.size_request ()
@@ -653,13 +652,6 @@ class Editor (Connector.Publisher):
         self.w.set_title (_("Edit entry"))
         self.w.connect ('delete_event', self.close_dialog)
 
-        # set window size
-        ui_width  = config.get_int ('Pybliographic/Editor/Width=-1')
-        ui_height = config.get_int ('Pybliographic/Editor/Height=-1')
-
-        if ui_width != -1 and ui_height != -1:
-            self.w.set_default_size (ui_width, ui_height)
-
         if parent: self.w.set_transient_for (parent)
 
         self.apply_b = GnomeStockButton (STOCK_BUTTON_APPLY)
@@ -705,6 +697,8 @@ class Editor (Connector.Publisher):
 
 
     def toggle_native (self, * arg):
+        self.save_size ()
+        
         if self.native_mode:
             # real edition
             self.native_mode = FALSE
@@ -714,11 +708,9 @@ class Editor (Connector.Publisher):
             if self.editor: self.editor.w.destroy ()
             self.editor = RealEditor (self.database,
                                       copy.deepcopy (self.entry))
-            self.editor.Subscribe ('apply', self.apply_changes)
-            self.editor.Subscribe ('next',  self.next_item)
-        
-            self.w.vbox.pack_start (self.editor.w)
-            self.editor.w.show ()
+            
+            ui_width  = config.get_int ('Pybliographic/Editor/Width=-1')
+            ui_height = config.get_int ('Pybliographic/Editor/Height=-1')
         else:
             # native edition
             self.native_mode = TRUE
@@ -728,12 +720,21 @@ class Editor (Connector.Publisher):
             if self.editor: self.editor.w.destroy ()
             self.editor = NativeEditor (self.database,
                                         copy.deepcopy (self.entry))
-            self.editor.Subscribe ('apply', self.apply_changes)
-            self.editor.Subscribe ('next',  self.next_item)
-        
-            self.w.vbox.pack_start (self.editor.w)
-            self.editor.w.show ()
 
+            ui_width  = config.get_int ('Pybliographic/Native/Width=-1')
+            ui_height = config.get_int ('Pybliographic/Native/Height=-1')
+
+
+        self.editor.Subscribe ('apply', self.apply_changes)
+        self.editor.Subscribe ('next',  self.next_item)
+        
+        self.w.vbox.pack_start (self.editor.w)
+
+        # set window size
+        if ui_width != -1 and ui_height != -1:
+            self.editor.w.set_usize(ui_width, ui_height)
+            
+        self.editor.w.show ()
         return
 
     
@@ -747,12 +748,21 @@ class Editor (Connector.Publisher):
         pass
 
 
-    def close_dialog (self, *arg):
-        alloc = self.w.get_allocation ()
-        config.set_int ('Pybliographic/Editor/Width',  alloc [2])
-        config.set_int ('Pybliographic/Editor/Height', alloc [3])
-        config.sync ()
+    def save_size (self):
+        if not self.editor: return
         
+        alloc = self.editor.w.get_allocation ()
+        if self.native_mode: field = 'Native'
+        else:                field = 'Editor'
+        
+        config.set_int ('Pybliographic/%s/Width' % field,  alloc [2])
+        config.set_int ('Pybliographic/%s/Height' % field, alloc [3])
+        config.sync ()
+        return
+
+    
+    def close_dialog (self, *arg):
+        self.save_size ()
         self.w.destroy ()
         return
 
