@@ -17,7 +17,9 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Pybliographic.py,v 1.9 2000/03/01 15:21:22 fredgo Exp $
+# $Id: Pybliographic.py,v 1.12 2000/04/04 08:32:56 fredgo Exp $
+
+''' Main Module holding all the documents '''
 
 import gettext, copy
 
@@ -27,22 +29,22 @@ from Pyblio.GnomeUI import Document
 from Pyblio import Base
 
 from gtk import *
-from gnome import config
+from gnome import config, history
 
 class Pybliographic:
     ''' Main class holding all the documents and performing
     general tasks '''
 
-    def __init__ (self, version):
-        self.version   = version
+    def __init__ (self):
         self.documents = []
 
-        self.opened = list (config.get_vector ('Pybliographic/Base/History='))
+        self.opened = filter (lambda x: x,
+                              list (config.get_vector ('Pybliographic/Base/History=')))
         return
 
     def new_document (self, * arg):
         db  = Base.DataBase (None)
-        doc = Document.Document (db, self.version)
+        doc = Document.Document (db)
 
         # register several callbacks
         doc.Subscribe ('new-document',     self.new_document)
@@ -59,7 +61,10 @@ class Pybliographic:
         ''' a document has been opened '''
 
         file = str (doc.data.key)
-        
+
+        history.recently_used (file, 'application/x-bibtex',
+                               'pybliographic', 'Bibliography')
+                              
         try:
             self.opened.remove (file)
         except ValueError:
@@ -71,6 +76,7 @@ class Pybliographic:
         for doc in self.documents:
             doc.update_history (self.opened)
         return
+
     
     def open_document (self, url, how = None):
         doc = self.new_document ()
@@ -97,7 +103,7 @@ class Pybliographic:
     def exit_application (self, document):
         document.update_configuration ()
         
-        config.set_vector ('Pybliographic/Base/History=',
+        config.set_vector ('Pybliographic/Base/History',
                            self.opened [0:10])
         config.sync ()
 
