@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Search.py,v 1.8 2000/04/04 08:32:56 fredgo Exp $
+# $Id: Search.py,v 1.10 2000/04/07 15:45:40 fredgo Exp $
 
 from gnome.ui import *
 from gtk import *
@@ -28,7 +28,6 @@ import string, re, sys, traceback, copy
 from Pyblio import Types, Search, Config, Connector, TextUI
 
 from Pyblio.GnomeUI import Utils
-from Pyblio.GnomeUI.Utils import TmpGnomeDialog
 
 import gettext
 _ = gettext.gettext
@@ -102,22 +101,23 @@ class ItemStorage (GtkTreeItem):
         return None
 
     
-class SearchDialog (TmpGnomeDialog, Connector.Publisher):
+class SearchDialog (GnomeDialog, Connector.Publisher):
     ''' Search Dialog '''
     
     def __init__ (self, parent = None):
 
-        TmpGnomeDialog.__init__ (self, _("Search"),
+        GnomeDialog.__init__ (self, _("Search"),
                               STOCK_PIXMAP_SEARCH,
                               STOCK_BUTTON_CLOSE)
         self.set_policy (TRUE, TRUE, FALSE)
         
         if parent: self.set_parent (parent)
 
-        self.button_connect (0, self.apply)
-        self.button_connect (1, self.close)
+        self.button_connect (0, self.apply_cb)
+        self.button_connect (1, self.close_cb)
         self.set_default (0)
         self.close_hides (1)
+        self.set_close (0)
         
         self.pairs   = []
         
@@ -138,7 +138,7 @@ class SearchDialog (TmpGnomeDialog, Connector.Publisher):
 
         self.text = GnomeEntry ('match')
         table.attach (self.text, 1, 2, 1, 2)
-        self.text.gtk_entry ().connect ('activate', self.apply)
+        self.text.gtk_entry ().connect ('activate', self.apply_cb)
 
         # fill the combo
         self.field.set_popdown_strings ([' - any field - '] +
@@ -153,7 +153,7 @@ class SearchDialog (TmpGnomeDialog, Connector.Publisher):
         hbox.pack_start (GtkLabel (_("Search command:")),
                          expand=FALSE, fill=FALSE)
         self.expert = GnomeEntry ('expert-search')
-        self.expert.gtk_entry ().connect ('activate', self.apply)
+        self.expert.gtk_entry ().connect ('activate', self.apply_cb)
         hbox.pack_start (self.expert)
         
         self.notebook.append_page (hbox, GtkLabel (_("Expert Search")))
@@ -195,9 +195,14 @@ class SearchDialog (TmpGnomeDialog, Connector.Publisher):
         self.root_tree.append (self.root_item)
         self.root_item.show ()
         return
+
+
+    def close_cb (self, widget):
+        self.close ()
+        return
     
     
-    def apply (self, widget):
+    def apply_cb (self, widget):
         page = self.notebook.get_current_page ()
 
         name = None
